Crate rusk_wallet

Crate rusk_wallet 

Dusk Wallet Lib

The dusk_wallet library aims to provide an easy and convenient way of interfacing with the Dusk Network.

Clients can use Wallet to create their Dusk wallet, send transactions through the network of their choice, stake and withdraw rewards, etc.

Modules

currency
Module to help with currency conversions.
dat
Methods for parsing/checking the DAT wallet file
gas
This module contains the primitive related to the gas used for transaction in the Dusk Network.

Structs

BlockTransaction
The tx_for_block returns a Vec which contains the dusk-core transaction, its id hash and gas spent
DecodedNote
This structs represent a Note decoded enriched with useful chain information
GraphQL
GraphQL is a helper struct that aggregates all queries done to the Dusk GraphQL database. This helps avoid having helper structs and boilerplate code mixed with the wallet logic.
Profile
Profile struct containing the addresses used for shielded and public transactions as well as for staking operations.
RuesHttpClient
Rusk HTTP Binary Client
Wallet
The interface to the Dusk Network
WalletPath
Wrapper around PathBuf for wallet paths

Enums

Address
Address to perform a transaction with.
Error
Errors returned by this library

Constants

EPOCH
The length of an epoch in blocks
MAX_CONTRACT_INIT_ARG_SIZE
Size for the init argument when deploying a contract
MAX_CONVERTIBLE
The largest amount of Dusk that is possible to convert
MAX_FUNCTION_NAME_SIZE
The maximum allowed size for function names, set to 64 bytes
MAX_PROFILES
Max addresses the wallet can store
MIN_CONVERTIBLE
The smallest amount of Dusk that is possible to convert

Traits

SecureWalletFile
Provides access to a secure wallet file