GraphQL

Struct GraphQL 

pub struct GraphQL { /* private fields */ }
GraphQL is a helper struct that aggregates all queries done to the Dusk GraphQL database. This helps avoid having helper structs and boilerplate code mixed with the wallet logic.

Implementations

Source

impl GraphQL

pub fn new<S: Into<String>>(url: S, status: fn(&str)) -> Result<Self, Error>

Create a new GraphQL wallet client

pub async fn wait_for(&self, tx_id: &str) -> Result<()>

Wait for a transaction to be confirmed (included in a block)

pub async fn txs_for_block( &self, block_height: u64, ) -> Result<Vec<BlockTransaction>, Error>

Obtain transactions inside a block

pub async fn check_connection(&self) -> Result<(), Error>

Sends an empty body to url to check if its available

pub async fn moonlight_history( &self, address: Address, ) -> Result<FullMoonlightHistory, Error>

Query the archival node for moonlight transactions given the BlsPublicKey

pub async fn moonlight_tx(&self, origin: &str) -> Result<Transaction, Error>

Fetch the spent transaction given moonlight tx hash

Source

impl GraphQL

pub async fn query(&self, query: &str) -> Result<Vec<u8>, Error>

Call the graphql endpoint of a node