Wallet

Struct Wallet 

pub struct Wallet<F: SecureWalletFile + Debug> { /* private fields */ }
The interface to the Dusk Network

The Wallet exposes all methods available to interact with the Dusk Network.

A new Wallet can be created from a bip39-compatible mnemonic phrase or an existing wallet file.

The user can generate as many Profile as needed without an active connection to the network by calling [Wallet::new_address] repeatedly.

A wallet must connect to the network using a [RuskEndpoint] in order to be able to perform common operations such as checking balance, transfernig funds, or staking Dusk.

Implementations

Source

impl<F: SecureWalletFile + Debug> Wallet<F>

pub async fn phoenix_transfer( &self, sender_idx: u8, receiver_pk: &PhoenixPublicKey, memo: Option<String>, amt: Dusk, gas: Gas, ) -> Result<Transaction, Error>

Transfers funds between shielded accounts.

pub async fn moonlight_transfer( &self, sender_idx: u8, rcvr: &BlsPublicKey, memo: Option<String>, amt: Dusk, gas: Gas, ) -> Result<Transaction, Error>

Transfers funds between public accounts.

pub async fn phoenix_execute( &self, sender_idx: u8, deposit: Dusk, gas: Gas, data: TransactionData, ) -> Result<Transaction, Error>

Executes a generic contract call, paying gas with a shielded account.

pub async fn moonlight_execute( &self, sender_idx: u8, transfer_value: Dusk, deposit: Dusk, gas: Gas, exec: Option<impl Into<TransactionData>>, ) -> Result<Transaction, Error>

Executes a generic contract call, paying gas from a public account.

pub async fn phoenix_stake( &self, profile_idx: u8, owner_idx: Option<u8>, amt: Dusk, gas: Gas, ) -> Result<Transaction, Error>

Stakes Dusk using shielded notes.

pub async fn moonlight_stake( &self, profile_idx: u8, owner_idx: Option<u8>, amt: Dusk, gas: Gas, ) -> Result<Transaction, Error>

Stakes Dusk using a public account.

pub async fn phoenix_unstake( &self, profile_idx: u8, gas: Gas, ) -> Result<Transaction, Error>

Unstakes Dusk into shielded notes.

pub async fn moonlight_unstake( &self, profile_idx: u8, gas: Gas, ) -> Result<Transaction, Error>

Unstakes Dusk onto a public account.

pub async fn phoenix_stake_withdraw( &self, sender_idx: u8, gas: Gas, ) -> Result<Transaction, Error>

Withdraws accumulated staking to a shielded account.

pub async fn moonlight_stake_withdraw( &self, sender_idx: u8, gas: Gas, ) -> Result<Transaction, Error>

Withdraws accumulated staking reward to a public account.

pub async fn phoenix_to_moonlight( &self, profile_idx: u8, amt: Dusk, gas: Gas, ) -> Result<Transaction, Error>

Converts Dusk from a shielded account to a public account.

pub async fn moonlight_to_phoenix( &self, profile_idx: u8, amt: Dusk, gas: Gas, ) -> Result<Transaction, Error>

Converts Dusk from a public account to a shielded account.

pub async fn phoenix_deploy( &self, sender_idx: u8, bytes_code: Vec<u8>, init_args: Vec<u8>, deploy_nonce: u64, gas: Gas, ) -> Result<Transaction, Error>

Deploys a contract using shielded notes to pay gas.

pub async fn moonlight_deploy( &self, sender_idx: u8, bytes_code: Vec<u8>, init_args: Vec<u8>, deploy_nonce: u64, gas: Gas, ) -> Result<Transaction, Error>

Deploys a contract using a public account to pay gas.

pub async fn find_stake_owner_idx( &self, stake_pk: &BlsPublicKey, ) -> Result<u8, Error>

Finds the index of the stake owner account.

pub async fn find_stake_owner_account( &self, stake_pk: &BlsPublicKey, ) -> Result<Address, Error>

Finds the address of the stake owner account.

Source

impl<F: SecureWalletFile + Debug> Wallet<F>

pub fn file(&self) -> &Option<F>

Returns the file used for the wallet

Source

impl<F: SecureWalletFile + Debug> Wallet<F>

pub fn new<P>(phrase: P) -> Result<Self, Error>
where P: Into<String>,

Creates a new wallet instance deriving its seed from a valid BIP39 mnemonic

pub fn from_file(file: F) -> Result<Self, Error>

Loads wallet given a session

pub fn save(&mut self) -> Result<(), Error>

Saves wallet to file from which it was loaded

pub fn save_to(&mut self, file: F) -> Result<(), Error>

Saves wallet to the provided file, changing the previous file path for the wallet if any. Note that any subsequent calls to [save] will use this new file.

pub fn state(&self) -> Result<&State, Error>

Access the inner state of the wallet

pub async fn connect_with_status<S: Into<String>>( &mut self, rusk_addr: S, prov_addr: S, status: fn(&str), ) -> Result<(), Error>

Connect the wallet to the network providing a callback for status updates

pub async fn sync(&self) -> Result<(), Error>

Sync wallet state

pub async fn register_sync(&mut self) -> Result<(), Error>

Helper function to register for async-sync outside of connect

pub async fn is_online(&self) -> bool

Checks if the wallet has an active connection to the network

pub async fn get_all_notes( &self, profile_idx: u8, ) -> Result<Vec<DecodedNote>, Error>

Fetches the notes from the state.

pub async fn get_phoenix_balance( &self, profile_idx: u8, ) -> Result<BalanceInfo, Error>

Get the Phoenix balance

pub async fn get_moonlight_balance( &self, profile_idx: u8, ) -> Result<Dusk, Error>

Get Moonlight account balance

pub fn add_profile(&mut self) -> u8

Pushes a new entry to the internal profiles vector and returns its index.

pub fn default_address(&self) -> Address

Returns the default address for this wallet

pub fn default_shielded_account(&self) -> Address

Returns the default shielded account address for this wallet

pub fn default_public_address(&self) -> Address

Returns the default public account address for this wallet

pub fn profiles(&self) -> &Vec<Profile>

Returns the profiles that have been generated by the user

pub fn shielded_key(&self, index: u8) -> Result<&PhoenixPublicKey, Error>

Returns the shielded key for a given index.

Errors

This will error if the wallet doesn’t have a profile stored for the given index.

pub fn public_key(&self, index: u8) -> Result<&BlsPublicKey, Error>

Returns the public account key for a given index.

Errors

This will error if the wallet doesn’t have a profile stored for the given index.

pub fn public_address(&self, index: u8) -> Result<Address, Error>

Returns the public account address for a given index.

pub fn shielded_account(&self, index: u8) -> Result<Address, Error>

Returns the shielded account address for a given index.

pub async fn stake_info( &self, profile_idx: u8, ) -> Result<Option<StakeData>, Error>

Obtains stake information for a given address.

pub fn provisioner_keys( &self, index: u8, ) -> Result<(BlsPublicKey, BlsSecretKey), Error>

Returns BLS key-pair for provisioner nodes

pub fn export_provisioner_keys( &self, profile_idx: u8, dir: &Path, filename: Option<String>, pwd: &[u8], ) -> Result<(PathBuf, PathBuf), Error>

Exports BLS key-pair for provisioners in node-compatible format

pub fn find_index(&self, addr: &Address) -> Result<u8, Error>

Return the index of the address passed, returns an error if the address is not in the wallet profiles.

pub fn claim(&self, addr: Address) -> Result<Address, Error>

Check if the address is stored in our profiles, return the address if found

pub fn get_contract_id( &self, profile_idx: u8, bytes: Vec<u8>, nonce: u64, ) -> Result<[u8; 32], Error>

Generate a contract id given bytes and nonce

pub fn get_file_version(&self) -> Result<DatFileVersion, Error>

Return the dat file version from memory or by reading the file In order to not read the file version more than once per execution

pub async fn is_synced(&self) -> Result<bool, Error>

Check if the wallet is synced

pub fn delete_cache(&mut self) -> Result<(), Error>

Erase the cache directory

pub fn close(&mut self)

Close the wallet and zeroize the seed

pub async fn get_mempool_gas_prices(&self) -> Result<MempoolGasPrices, Error>

Get gas prices from the mempool