pub enum Error {
Show 49 variants
Offline,
Unauthorized,
Rusk(String),
IO(Error),
Json(Error),
Bytes(Error),
Base58(Error),
Rkyv,
HttpClient,
Reqwest(Error),
Utf8(Utf8Error),
Rng(Error),
NotEnoughBalance,
AmountIsZero,
NoteCombinationProblem,
NoteNotFound,
WrongViewKey,
NotEnoughGas,
NotStaked,
NoReward,
BadAddress,
AddressNotOwned,
NoMenuItemSelected,
InvalidMnemonicPhrase,
NotDirectory,
OsNotSupported,
WalletFileCorrupted,
UnknownFileVersion(u8, u8),
WalletFileExists,
WalletFileMissing,
BlockMode(BlockModeError),
AttemptsExhausted,
StatusWalletConnected,
Transaction(String),
RocksDB(Error),
NetworkNotFound,
CacheDatabaseCorrupted,
ProverError(String),
MemoTooLarge(usize),
ExpectedBlsPublicKey,
ExpectedPhoenixPublicKey,
DifferentTransactionModels,
InvalidContractId,
InvalidWasmContractPath,
InvalidEnvVar(String),
Conversion(String),
GraphQLError(GraphQLError),
InquireError(String),
ArchiveJsonError(String),
}Expand description
Errors returned by this library
Variants
Offline
Command not available in offline mode
Unauthorized access to this address
Rusk(String)
Rusk error
IO(Error)
Filesystem errors
Json(Error)
JSON serialization errors
Bytes(Error)
Bytes encoding errors
Base58(Error)
Base58 errors
Rkyv
Rkyv errors
HttpClient
Error creating HTTP client
Reqwest(Error)
Reqwest errors
Utf8(Utf8Error)
Utf8 errors
Rng(Error)
Random number generator errors
NotEnoughBalance
Not enough balance to perform transaction
AmountIsZero
Amount to transfer/stake cannot be zero
NoteCombinationProblem
Note combination for the given value is impossible given the maximum amount of inputs in a transaction
NoteNotFound
The note wasn’t found in the note-tree of the transfer-contract
WrongViewKey
The note couldn’t be decrypted with the provided ViewKey
NotEnoughGas
Not enough gas to perform this transaction
NotStaked
A stake does not exist for this key
NoReward
No reward available for this key
BadAddress
Invalid address
AddressNotOwned
Address does not belong to this wallet
NoMenuItemSelected
No menu item selected
InvalidMnemonicPhrase
Mnemonic phrase is not valid
NotDirectory
Path provided is not a directory
OsNotSupported
Cannot get the path to the $HOME directory
WalletFileCorrupted
Wallet file content is not valid
UnknownFileVersion(u8, u8)
File version not recognized
WalletFileExists
A wallet file with this name already exists
WalletFileMissing
Wallet file is missing
BlockMode(BlockModeError)
Wrong wallet password
AttemptsExhausted
Reached the maximum number of attempts
StatusWalletConnected
Status callback needs to be set before connecting
Transaction(String)
Transaction error
RocksDB(Error)
Rocksdb cache database error
NetworkNotFound
Provided Network not found
CacheDatabaseCorrupted
The cache database couldn’t find column family required
ProverError(String)
Prover errors from dusk-core
MemoTooLarge(usize)
Memo provided is too large
ExpectedBlsPublicKey
Expected BLS Key
ExpectedPhoenixPublicKey
Expected Phoenix public key
DifferentTransactionModels
Addresses use different transaction models
InvalidContractId
Invalid contract id provided
InvalidWasmContractPath
Contract file location not found
InvalidEnvVar(String)
Invalid environment variable value
Conversion(String)
Conversion error
GraphQLError(GraphQLError)
GraphQL error
InquireError(String)
Inquire error
ArchiveJsonError(String)
Error while querying archival node